@@ -4,8 +4,8 @@
 * acp_board [Chinese Simplified]
 *
 * @package language
-* @version $Id: board.php 8554 2008-05-15 13:29:14Z Kellanved $
-* @copyright (c) 2007 phpbbchina.com
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -108,7 +108,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> '最大头像尺寸',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> '(用像素表示的宽 x 高)',
 	'MAX_FILESIZE'					=> '最大的头像文件大小',
-	'MAX_FILESIZE_EXPLAIN'			=> '针对上载的头像文件',
+	'MAX_FILESIZE_EXPLAIN'			=> '针对上载的头像文件，如果设为0的话上传文件大小只受限于您的 PHP 配置。',
 	'MIN_AVATAR_SIZE'				=> '最小的头像文件大小',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> '(用像素表示的宽 x 高)',
 ));
