@@ -4,8 +4,8 @@
 * acp_common [Chinese Simplified]
 *
 * @package language
-* @version $Id: common.php 8591 2012-1-15 11:40:53Z tabwe $
-* @copyright (c) 2007 phpbbchina.com
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -95,11 +95,11 @@ $lang = array_merge($lang, array(
 	'ACP_GENERAL_TASKS'				=> '一般任务',
 	'ACP_GLOBAL_MODERATORS'			=> '超级版主',
 	'ACP_GLOBAL_PERMISSIONS'		=> '全局权限',
-	'ACP_GROUPS'					=> '用户组',
-	'ACP_GROUPS_FORUM_PERMISSIONS'	=> '用户组的版面权限',
-	'ACP_GROUPS_MANAGE'				=> '管理用户组',
-	'ACP_GROUPS_MANAGEMENT'			=> '用户组管理',
-	'ACP_GROUPS_PERMISSIONS'		=> '用户组权限',
+	'ACP_GROUPS'					=> '组',
+	'ACP_GROUPS_FORUM_PERMISSIONS'	=> '组版面权限',
+	'ACP_GROUPS_MANAGE'				=> '管理组',
+	'ACP_GROUPS_MANAGEMENT'			=> '组管理',
+	'ACP_GROUPS_PERMISSIONS'		=> '组权限',
 
 	'ACP_ICONS'					=> '主题图标',
 	'ACP_ICONS_SMILIES'			=> '主题图标/表情',
@@ -172,9 +172,9 @@ $lang = array_merge($lang, array(
 	'ACP_THEMES'				=> '风格主题',
 
 	'ACP_UPDATE'					=> '更新中',
-	'ACP_USERS_FORUM_PERMISSIONS'	=> '用户的版面权限',
+	'ACP_USERS_FORUM_PERMISSIONS'	=> '用户版面权限',
 	'ACP_USERS_LOGS'				=> '用户日志',
-	'ACP_USERS_PERMISSIONS'			=> '用户的权限',
+	'ACP_USERS_PERMISSIONS'			=> '用户权限',
 	'ACP_USER_ATTACH'				=> '附件',
 	'ACP_USER_AVATAR'				=> '头像',
 	'ACP_USER_FEEDBACK'				=> '反馈',
@@ -405,7 +405,7 @@ $lang = array_merge($lang, array(
 	'INACTIVE_REASON_UNKNOWN'		=> '未知',
 	'INACTIVE_USERS'				=> '冻结的用户',
 	'INACTIVE_USERS_EXPLAIN'		=> '这是已经注册但是没有激活的用户列表. 您可以删除或提醒 (发送email) 他们.',
-	'INACTIVE_USERS_EXPLAIN_INDEX'	=> '这是最近十个未激活的用户列表. 您可以通过下面的链接查看完整列表并进行激活、删除或email通知操作.',
+	'INACTIVE_USERS_EXPLAIN_INDEX'	=> '这是最近10个已注册但未激活的用户列表，账户未激活可能是因为在用户注册设置里已启用账户激活但这些用户还没被激活，也可能因为这些账户已失效。点击下面的链接可得到一份完整的列表，如果您想的话可以激活、删除或提醒（通过 email）这些用户。',
 
 	'NO_INACTIVE_USERS'	=> '没有冻结的用户',
 
