@@ -4,8 +4,8 @@
 * acp_permissions [Chinese Simplified]
 *
 * @package language
-* @version $Id: permissions.php 8479 2008-03-29 00:22:48Z naderman $
-* @copyright (c) 2007 phpbbchina.com
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -40,10 +40,10 @@ $lang = array_merge($lang, array(
 		<p>权限具有很高的粒度, 合并为四个主要权限组:</p>
 
 		<h2>全局权限</h2>
-		<p>用于管理整个论坛的全局访问, 并进一步区分为用户权限, 管理员权限和超级版主权限.</p>
+		<p>用于控制全局访问, 适用于整个论坛，进一步划分为用户权限、组权限、管理员和超级版主。</p>
 
 		<h2>版面权限</h2>
-		<p>针对每个版面的权限控制, 进一步分为版面权限, 版主版面权限, 用户版面权限, 用户组版面权限.</p>
+		<p>用于控制基于版面的访问，进一步分为版面权限、版面版主、用户版面权限和组版面权限。</p>
 
 		<h2>权限角色</h2>
 		<p>用于创建不同的权限组, 以便于设定不同的角色权限. 默认的角色可以或大或小的覆盖论坛的管理权限, 不过在这四个权限组中您也可以添加/编辑/删除您觉得合适的角色.</p>
@@ -83,13 +83,13 @@ $lang = array_merge($lang, array(
 	'ACP_FORUM_PERMISSIONS_COPY_EXPLAIN'		=> '这里您可以将一个版面的权限复制到其他版面.',
 	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> '这里您可以设定用户/组为超级版主. 这些版主拥有一般的版主权限, 但是他们可以访问论坛的每个版面.',
 	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'		=> '这里您可以设置用户组的版面权限.',
-	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> '这里您可以将全局权限设定到权限组 - 用户权限, 超级版主权限和管理员权限. 用户权限包含使用头像, 发送私人信件等等, 超级版主权限包含审阅帖子, 管理主题, 管理封禁等等, 而管理员权限包含更改权限, 设定BBCode, 管理版面等等. 只有少数的情况下才需要单独的用户权限设置, 推荐的方式是将用户归类到不同的组, 再赋予组不同的权限.',
+	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> '这里您可以将全局权限分配到组 - 用户权限、超级版主权限和管理员权限。用户权限包括的功能如使用头像、发送私信等等；超级版主权限如批准帖子、管理主题、管理封禁等等；终极管理员权限如变更权限、设定 BBCode、管理版面等等。只有在少数的情况下才需要改变单个用户权限，优先方法是将用户归组然后分配组权限。',
 	'ACP_ADMIN_ROLES_EXPLAIN'					=> '这里您可以管理管理员权限的角色. 角色是一种有效的权限组合, 如果您更改了角色内容, 那么使用这个角色的对象就会相应的被更改权限.',
 	'ACP_FORUM_ROLES_EXPLAIN'					=> '这里您可以管理版面权限的角色. 角色是有效的权限组合, 如果您更改了角色内容, 那么使用这个角色的对象就会相应的被更改权限.',
 	'ACP_MOD_ROLES_EXPLAIN'						=> '这里您可以管理版主权限的角色. 角色是有效的权限组合, 如果您更改了角色内容, 那么使用这个角色的对象就会相应的被更改权限.',
 	'ACP_USER_ROLES_EXPLAIN'					=> '这里您可以管理用户权限的角色. 角色是有效的权限组合, 如果您更改了角色内容, 那么使用这个角色的对象就会相应的被更改权限.',
-	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> '这里您可以为用户设定权限.',
-	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> '这里您可以给用户设定全局权限 - 用户权限, 超级版主权限和管理员权限. 用户权限包含使用头像, 发送站内短信等等; 超级版主权限包含审阅帖子, 管理主题, 管理封禁等等; 管理员权限包含权限设定, BBCode设置, 版面管理等等. 对于大规模的用户权限设定请使用用户组权限方式. 用户的单独权限只在很少数的情况下需要更改, 推荐的方式是将用户归类在不同的用户组中, 再赋予用户组不同的权限.',
+	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> '这里您可以为用户分配版面权限。',
+	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> '这里您可以给用户分配全局权限 - 用户权限、超级版主权限和管理员权限。用户权限包括的功能如使用头像、发送私信等等；超级版主权限如批准帖子、管理主题、管理封禁等等；终极管理员权限如变更权限、定义 BBCode、版面管理等等。要变更大量用户的权限推荐使用组权限系统，用户权限应该极少被变更，优先的方法是将用户归组然后分配组权限。',
 	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'		=> '这里您可以查看给选中的用户/组设定的有效管理权限',
 	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS_EXPLAIN'	=> '这里您可以查看给选中的用户/组设定的有效版主权限',
 	'ACP_VIEW_FORUM_PERMISSIONS_EXPLAIN'		=> '这里您可以查看给选中的用户/组和版面设定的有效版面权限',
@@ -181,7 +181,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> '无头像',
 	'ROLE_USER_NOPM'			=> '无私人短信',
 	'ROLE_USER_STANDARD'		=> '标准功能',
-	'ROLE_USER_NEW_MEMBER'		=> '新注册用户特性',
+	'ROLE_USER_NEW_MEMBER'		=> '新注册用户功能',
 
 	
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> '可以访问论坛管理和论坛权限设置.',
