@@ -1,12 +1,12 @@
 <?php
-/** 
+/**
 *
 * common [Chinese Simplified]
 *
 * @package language
-* @version $Id: common.php 9046 2008-11-02 16:19:11Z acydburn $
-* @copyright (c) 2007 phpbbchina.com
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -35,12 +35,12 @@ if (empty($lang) || !is_array($lang))
 // equally where a string contains only two placeholders which are used to wrap text
 // in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
 //
-// Some characters you may want to copy&paste: 
+// Some characters you may want to copy&paste:
 // ’ » “ ” …
 //
 
 $lang = array_merge($lang, array(
-	'TRANSLATION_INFO'	=> '简体中文语系由 <a href="http://www.phpbbchina.com/creditinfo">PHPBB中文翻译小组</a> 维护制作',
+	'TRANSLATION_INFO'	=> '简体中文语系由 <a href="mailto:48596@qq.com">王笑宇</a> 翻译',
 	'DIRECTION'			=> 'ltr',
 	'DATE_FORMAT'		=> '|d M Y|', // 01 Jan 2007 (with Relative days enabled)
 	'USER_LANG'			=> 'zh-cmn-hans',
@@ -191,7 +191,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'			=> '提交的表单无效, 请再尝试一次.',
 	'FORUM'					=> '版面',
 	'FORUMS'				=> '版面',
-	'FORUMS_MARKED'			=> '选择的版面已被标记为已读。',
+	'FORUMS_MARKED'			=> '版面已被标记为已读。',
 	'FORUM_CAT'				=> '版面类别',
 	'FORUM_INDEX'			=> '论坛首页',
 	'FORUM_LINK'			=> '版面链接',
@@ -450,6 +450,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> '发表时间',
 	'POST_TOPIC'			=> '发表主题',
 	'POST_UNAPPROVED'		=> '这篇帖子正在等待批阅',
+	'POWERED_BY'			=> '由 %s 提供支持',
 	'PREVIEW'				=> '预览',
 	'PREVIOUS'				=> '上一页', 		// Used in pagination
 	'PREVIOUS_STEP'			=> '上一步',
@@ -459,6 +460,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'		=> '私人短信',
 	'PROFILE'				=> '用户控制面板',
 
+	'RANK'						=> '等级',
 	'READING_FORUM'				=> '查看 %s 版面的主题',
 	'READING_GLOBAL_ANNOUNCE'	=> '查看全站公告',
 	'READING_LINK'				=> '转向版面链接 %s',
@@ -673,8 +675,8 @@ $lang = array_merge($lang, array(
 	'USER_POSTS'			=> '%d 篇帖子',
 	'USERS'					=> '用户',
 	'USE_PERMISSIONS'		=> '检查用户的权限',
-	'USER_NEW_PERMISSION_DISALLOWED'	=> '很抱歉您还不能使用此功能. 作为新注册的用户您需要更多的参与后才能使用这些功能.',
-	'USER_NEW_PERMISSION_DISALLOWED'	=> '很抱歉!您没有权限使用这个功能。您只是刚在本站注册，您需要有更多的参与，才可使用这个功能。',
+
+	'USER_NEW_PERMISSION_DISALLOWED'	=> '抱歉!您没有权限使用这个功能。您刚在本站注册，等级不够。',
 
 	'VARIANT_DATE_SEPARATOR'	=> ' / ',	// Used in date format dropdown, eg: "Today, 13:37 / 01 Jan 2007, 13:37" ... to join a relative date with calendar date
 	'VIEWED'					=> '已读',
@@ -889,4 +891,4 @@ $lang = array_merge($lang, array(
 
 ));
 
-?>
+?>
\ No newline at end of file
