@@ -1,12 +1,12 @@
 <?php
-/** 
+/**
 *
 * help_faq [Chinese Simplified]
 *
 * @package language
-* @version $Id: help_faq.php 8479 2008-03-29 00:22:48Z naderman $
-* @copyright (c) 2007 phpbbchina.com 
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -72,7 +72,7 @@ $help = array(
 	),
 	array(
 		0 => '“清除论坛 cookie” 是什么意思?',
-		1 => '删除所有phpBB3在您的电脑上留下的cookies. 这些cookie包含您在论坛上的认证信息和您在论坛上的阅读记录等信息.',
+		1 => '删除所有phpBB在您的电脑上留下的cookies. 这些cookie包含您在论坛上的认证信息和您在论坛上的阅读记录等信息.',
 	),
 	array(
 		0 => '--',
@@ -332,8 +332,8 @@ $help = array(
 		1 => '这份软件 (官方发行的版本) 由 <a href="http://www.phpbb.com/">phpBB Group</a> 制作, 发布并持有版权. 遵循 GNU General Public Licence 开源协议, 可以自由使用和发布, 查看链接以得到更多信息'
 	),
 	array(
-		0 => '为什么没有XXX功能?',
-		1 => '这份软件由 phpBB Group 编写并许可发行. 如果您觉得这个功能有必要添加, 请访问 phpbb.com 网站看看 phpBB 开发团队是怎么说的. 请不要在phpbb.com 的版面上提出功能需求, 开发小组使用 sourceforge 来处理这类事务. 请查找论坛看看是否有类似的请求, 或许我们已经对这种功能有详尽的回答.'
+		0 => '为什么没有 X 功能?',
+		1 => '本软件由 phpBB Group 编写和授权，如果您认为某个功能需要被添加，或者想报告 bug，请访问 phpBB <a href="http://area51.phpbb.com/">Area51</a> 网站，在这里可以找到所需资源。'
 	),
 	array(
 		0 => '对于论坛上诽谤, 脏话和其他触及法律的事务, 我该联络谁?',
