@@ -1,12 +1,12 @@
 <?php
-/** 
+/**
 *
 * install [Chinese Simplified]
 *
 * @package language
-* @version $Id: install.php 8598 2008-06-04 15:37:06Z naderman $
-* @copyright (c) 2007 phpbbchina.com
-* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
+* @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
 
@@ -52,6 +52,7 @@ $lang = array_merge($lang, array(
 	'BLANK_PREFIX_FOUND'			=> '对数据库的扫描显示存在可用的无前缀表单。',
 	'BOARD_NOT_INSTALLED'			=> '没有发现已安装的phpBB',
 	'BOARD_NOT_INSTALLED_EXPLAIN'	=> '为了进行转换您必须预先安装一个全新的 phpBB3。请注意新的安装数据要和旧的数据存在同一个数据库里，您是否要进行【<a href="%s">全新安装</a>】？',
+	'BACKUP_NOTICE'					=> '升级前请备份您的论坛，防止升级过程中出现问题。',
 
 	'CATEGORY'					=> '分区',
 	'CACHE_STORE'				=> '缓存类型',
@@ -624,7 +625,7 @@ $lang = array_merge($lang, array(
 	'SMILIES_VERY_HAPPY'			=> '特开心',
 	'SMILIES_WINK'					=> '眨眼',
 
-	'TOPICS_TOPIC_TITLE'			=> '欢迎来到phpBB3',
+	'TOPICS_TOPIC_TITLE'			=> '欢迎来到 phpBB3',
 ));
 
 ?>
\ No newline at end of file
