@@ -1,11 +1,11 @@
 <?php
-/** 
+/**
 *
 * ucp [Chinese Simplified]
 *
 * @package language
-* @version $Id: ucp.php 8479 2008-03-29 00:22:48Z naderman $
-* @copyright (c) 2007 phpbbchina.com
+* @version $Id$
+* @copyright (c) 2005 phpBB Group
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 *
 */
@@ -137,7 +137,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'				=> '添加文件夹',
 	'CURRENT_IMAGE'				=> '当前图片',
 	'CURRENT_PASSWORD'			=> '当前密码',
-	'CURRENT_PASSWORD_EXPLAIN'	=> '如果您希望修改密码，email地址或者用户名，您必须确认您当前的密码。',
+	'CURRENT_PASSWORD_EXPLAIN'	=> '如果想修改email或者用户名，您必须输入您现在的密码。',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => '要修改密码、email或用户名，您必须输入您现在的密码',
 	'CUR_PASSWORD_EMPTY'		=> '您没有输入您的当前密码。',
 	'CUR_PASSWORD_ERROR'		=> '您输入的当前密码不正确。',
 	'CUSTOM_DATEFORMAT'			=> '自定义……',
@@ -387,6 +388,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> '规则已经添加',
 	'RULE_ALREADY_DEFINED'				=> '这个规则已经存在',
 	'RULE_DELETED'						=> '规则已经移除',
+	'RULE_LIMIT_REACHED'				=> '您不能再添加私信规则，已到达规则数上限。',
 	'RULE_NOT_DEFINED'					=> '没有正确指定规则',
 	'RULE_REMOVED_MESSAGE'				=> '一条私人短信被过滤删除。',
 	'RULE_REMOVED_MESSAGES'				=> '%d 私人短信被过滤删除。',
@@ -558,4 +560,4 @@ $lang = array_merge($lang, array(
 	'NO_NONMEMBER'	=> '没有非组成员',
 ));
 
-?>
+?>
\ No newline at end of file
